==> cloud-4.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/k8s/js/k8s_project_costs_horizon_chart.js <==
(function ($) {
  'use strict';

  let color = d3.interpolateSpectral;
  if (!drupalSettings.k8s || !drupalSettings.k8s.k8s_project_costs_chart_json_url) {
    return;
  }

  let cost_type = null;
  let chart_period = null;
  if (drupalSettings.k8s.k8s_project_costs_chart_ec2_cost_type) {
    cost_type = drupalSettings.k8s.k8s_project_costs_chart_ec2_cost_type;
  }
  chart_period = drupalSettings.k8s.k8s_project_costs_chart_period
    ? drupalSettings.k8s.k8s_project_costs_chart_period
    : 1;

  $('#k8s_project_costs_chart').append('<div id="project_chart_options">');
  $('#project_chart_options').css('font-size', 'x-small');
  $('#project_chart_options').css('text-align', 'right');
  $('#project_chart_options').append('<span>');
  $('#project_chart_options').append('<span>');
  if (drupalSettings.k8s.k8s_project_costs_cost_types_json_url) {
    let cost_types_json_url = drupalSettings.k8s.k8s_project_costs_cost_types_json_url;
    $.get(cost_types_json_url, function (json) {
      $('#project_chart_options > span:first-child').append('<label for="project_cost_type">' + Drupal.t('Cost Type') + '</label>');
      $('#project_chart_options > span:first-child').append('<select id="project_cost_type">');
      $.each(json, function (index, value) {
        $('#project_cost_type').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#project_cost_type option').css('font-size', 'x-small');
      if (cost_type) {
        $('#project_cost_type').val(cost_type);
      }
      $('#project_cost_type').change(function () {
        updateChart();
      });
    });
  }
  if (drupalSettings.k8s.k8s_project_costs_chart_periods_json_url) {
    let chart_periods_json_url = drupalSettings.k8s.k8s_project_costs_chart_periods_json_url;
    $.get(chart_periods_json_url, function (json) {
      $('#project_chart_options > span:last-child').append('<label for="project_chart_period">' + Drupal.t('Chart Period') + '</label>');
      $('#project_chart_options > span:last-child label').css('margin-left', '10px');
      $('#project_chart_options > span:last-child').append('<select id="project_chart_period">');
      $.each(json, function (index, value) {
        $('#project_chart_period').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#project_chart_period option').css('font-size', 'x-small');

      if (chart_period && $('select#project_chart_period option[value="' + chart_period + '"]').length > 0) {
        $('#project_chart_period').val(chart_period);
      }
      else if ($('select#project_chart_period option[value="1"]').length > 0) {
        $('#project_chart_period').val(1);
      }
      $('#project_chart_period').change(function () {
       updateChart();
      });
    });
  }

  let json_url = drupalSettings.k8s.k8s_project_costs_chart_json_url;

  let initChart = function () {
    let init_json_url = json_url + '?' + 'cost_type=' + cost_type + '&period=' + chart_period;
    d3.json(init_json_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function (idx) {
        let project = this.project;
        let selector = project.replace(':' , '--');
        let cost_data = [];
        $.each(this.costs, function () {
          cost_data.push([
            new Date(this.timestamp * 1000),
            this.cost
          ]);
        });
        chart_datas.push({
          id: project,
          values: cost_data,
          selector: '#' + selector,
        });

        $('#k8s_project_costs_chart').append('<div id="' + selector + '"></div>');
      });

      Drupal.Cloud.drawChart(chart_datas, true);
    });

  };

  let updateChart = function () {
    let update_json_url = json_url + '?' + 'cost_type=' + $('#project_cost_type').val() + '&period=' + $('#project_chart_period').val();
    d3.json(update_json_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function () {
        let project = this.project;
        let selector = project.replace(':' , '--');
        let cost_data = [];
        $.each(this.costs, function () {
          cost_data.push([
            new Date(this.timestamp * 1000),
            this.cost
          ]);
        });
        chart_datas.push({
          id: project,
          values: cost_data,
          selector: '#' + selector,
        });
      });

      Drupal.Cloud.drawChart(chart_datas, true);
    });
  };

  initChart();

  let interval = drupalSettings.k8s.k8s_js_refresh_interval || 10;
  setInterval(function () {
    updateChart();
  }, interval * 1000);

})(jQuery);

==> cloud-5.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/k8s/js/k8s_project_costs_horizon_chart.js <==
(function ($) {
  'use strict';

  let color = d3.interpolateSpectral;
  if (!drupalSettings.k8s || !drupalSettings.k8s.k8s_project_costs_chart_json_url) {
    return;
  }

  let cost_type = null;
  let chart_period = null;
  if (drupalSettings.k8s.k8s_project_costs_chart_ec2_cost_type) {
    cost_type = drupalSettings.k8s.k8s_project_costs_chart_ec2_cost_type;
  }
  chart_period = drupalSettings.k8s.k8s_project_costs_chart_period
    ? drupalSettings.k8s.k8s_project_costs_chart_period
    : 1;

  $('#k8s_project_costs_chart').append('<div id="project_chart_options">');
  $('#project_chart_options').css('font-size', 'x-small');
  $('#project_chart_options').css('text-align', 'right');
  $('#project_chart_options').append('<span>');
  $('#project_chart_options').append('<span>');
  if (drupalSettings.k8s.k8s_project_costs_cost_types_json_url) {
    let cost_types_json_url = drupalSettings.k8s.k8s_project_costs_cost_types_json_url;
    $.get(cost_types_json_url, function (json) {
      $('#project_chart_options > span:first-child').append('<label for="project_cost_type">' + Drupal.t('Cost type') + '</label>');
      $('#project_chart_options > span:first-child').append('<select id="project_cost_type">');
      $.each(json, function (index, value) {
        $('#project_cost_type').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#project_cost_type option').css('font-size', 'x-small');
      if (cost_type) {
        $('#project_cost_type').val(cost_type);
      }
      $('#project_cost_type').change(function () {
        updateChart();
      });
    });
  }
  if (drupalSettings.k8s.k8s_project_costs_chart_periods_json_url) {
    let chart_periods_json_url = drupalSettings.k8s.k8s_project_costs_chart_periods_json_url;
    $.get(chart_periods_json_url, function (json) {
      $('#project_chart_options > span:last-child').append('<label for="project_chart_period">' + Drupal.t('Chart period') + '</label>');
      $('#project_chart_options > span:last-child label').css('margin-left', '10px');
      $('#project_chart_options > span:last-child').append('<select id="project_chart_period">');
      $.each(json, function (index, value) {
        $('#project_chart_period').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#project_chart_period option').css('font-size', 'x-small');

      if (chart_period && $('select#project_chart_period option[value="' + chart_period + '"]').length > 0) {
        $('#project_chart_period').val(chart_period);
      }
      else if ($('select#project_chart_period option[value="1"]').length > 0) {
        $('#project_chart_period').val(1);
      }
      $('#project_chart_period').change(function () {
       updateChart();
      });
    });
  }

  let json_url = drupalSettings.k8s.k8s_project_costs_chart_json_url;

  let initChart = function () {
    let init_json_url = json_url + '?' + 'cost_type=' + cost_type + '&period=' + chart_period;
    d3.json(init_json_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function (idx) {
        let project = this.project;
        let selector = project.replace(':' , '--');
        let cost_data = [];
        $.each(this.costs, function () {
          cost_data.push([
            new Date(this.timestamp * 1000),
            this.cost
          ]);
        });
        chart_datas.push({
          id: project,
          values: cost_data,
          selector: '#' + selector,
        });

        $('#k8s_project_costs_chart').append('<div id="' + selector + '"></div>');
      });

      Drupal.Cloud.drawChart(chart_datas, true);
    });

  };

  let updateChart = function () {
    let update_json_url = json_url + '?' + 'cost_type=' + $('#project_cost_type').val() + '&period=' + $('#project_chart_period').val();
    d3.json(update_json_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function () {
        let project = this.project;
        let selector = project.replace(':' , '--');
        let cost_data = [];
        $.each(this.costs, function () {
          cost_data.push([
            new Date(this.timestamp * 1000),
            this.cost
          ]);
        });
        chart_datas.push({
          id: project,
          values: cost_data,
          selector: '#' + selector,
        });
      });

      Drupal.Cloud.drawChart(chart_datas, true);
    });
  };

  initChart();

  let interval = drupalSettings.k8s.k8s_js_refresh_interval || 10;
  setInterval(function () {
    updateChart();
  }, interval * 1000);

})(jQuery);
